
import React from 'react';
import { motion } from 'framer-motion';
import { MapPin, Target, Zap, Users } from 'lucide-react';
import { Button } from '@/components/ui/button';

const ServiceCard = ({ icon, title, description, imageText, altText }) => {
  const IconComponent = icon;
  return (
    <motion.div
      className="bg-white/10 backdrop-blur-md p-6 rounded-xl shadow-lg hover:shadow-2xl transition-shadow duration-300 border border-white/20 flex flex-col items-center text-center"
      whileHover={{ y: -5, scale: 1.03 }}
    >
      <div className="w-full h-48 mb-4 rounded-lg overflow-hidden">
        <img  class="w-full h-full object-cover" alt={altText} src="https://images.unsplash.com/photo-1675023112817-52b789fd2ef0" />
      </div>
      <div className="p-4 bg-purple-600 rounded-full mb-4 inline-block shadow-md">
        <IconComponent size={32} className="text-yellow-400" />
      </div>
      <h3 className="text-2xl font-semibold text-white mb-3">{title}</h3>
      <p className="text-white/80 text-sm leading-relaxed">{description}</p>
    </motion.div>
  );
};

const ServicesSection = () => {
  return (
    <section id="services" className="py-16 md:py-24 bg-gradient-to-b from-indigo-700 to-purple-800">
      <div className="container mx-auto px-4">
        <motion.h2
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.6 }}
          className="text-4xl md:text-5xl font-bold text-center text-yellow-400 mb-6"
        >
          Reklam Güzergahları ve Hizmetlerimiz
        </motion.h2>
        <motion.p 
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.6, delay:0.1 }}
          className="text-center text-white/90 mb-16 max-w-2xl mx-auto text-lg"
        >
          Markanızın mesajını şehrin en işlek noktalarına taşıyoruz. Hedef kitlenize özel, dikkat çekici ve etkileşimli reklam kampanyaları tasarlıyoruz.
        </motion.p>
        <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-4 gap-8 mb-12">
          <ServiceCard
            icon={MapPin}
            title="Özdilek Bölgesi"
            description="Alışveriş merkezleri ve yoğun yaya trafiği ile dikkat çeken bir nokta."
            imageText="Map view of Özdilek area"
            altText="Özdilek Reklam Alanı"
          />
          <ServiceCard
            icon={Target}
            title="PSM Bulvarı"
            description="Kültür, sanat ve eğlence merkezlerinin kalbi. Genç ve dinamik kitleye ulaşın."
            imageText="Map view of PSM Boulevard"
            altText="PSM Bulvarı Reklam Alanı"
          />
          <ServiceCard
            icon={Zap}
            title="Görükle Merkezi"
            description="Üniversite öğrencilerinin ve genç profesyonellerin yoğun olduğu bölge."
            imageText="Map view of Görükle center"
            altText="Görükle Reklam Alanı"
          />
          <ServiceCard
            icon={Users}
            title="Mudanya Sahili"
            description="Turistik ve yerel halkın uğrak noktası, özellikle yaz aylarında yüksek görünürlük."
            imageText="Map view of Mudanya coastline"
            altText="Mudanya Sahili Reklam Alanı"
          />
        </div>
        <motion.div 
          className="text-center mt-12"
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.6, delay:0.2 }}
        >
          <p className="text-white/80 mb-4 text-lg">Aradığınız güzergahı bulamadınız mı? Özel rotalar için bizimle iletişime geçin!</p>
          <Button 
            size="lg" 
            className="bg-gradient-to-r from-yellow-400 to-orange-500 text-purple-900 font-bold hover:from-yellow-500 hover:to-orange-600 transition-all duration-300 transform hover:scale-105 shadow-xl px-10 py-3 text-lg rounded-full"
            onClick={() => document.getElementById('contact')?.scrollIntoView({ behavior: 'smooth' })}
          >
            Reklam Verin
          </Button>
        </motion.div>
      </div>
    </section>
  );
};

export default ServicesSection;
